import { setComponentTemplate } from '@ember/component';
import { precompileTemplate } from '@ember/template-compilation';
import { action, get } from '@ember/object';
import Component from '@glimmer/component';
import { cached } from '@glimmer/tracking';
import { getOwner } from '@ember/application';
import { isPresent } from '@ember/utils';

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
  var desc = {};
  Object.keys(descriptor).forEach(function (key) {
    desc[key] = descriptor[key];
  });
  desc.enumerable = !!desc.enumerable;
  desc.configurable = !!desc.configurable;
  if ('value' in desc || desc.initializer) {
    desc.writable = true;
  }
  desc = decorators.slice().reverse().reduce(function (desc, decorator) {
    return decorator(target, property, desc) || desc;
  }, desc);
  if (context && desc.initializer !== void 0) {
    desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
    desc.initializer = undefined;
  }
  if (desc.initializer === void 0) {
    Object.defineProperty(target, property, desc);
    desc = null;
  }
  return desc;
}

var TEMPLATE = precompileTemplate("<div class=\"h-captcha\" ...attributes {{did-insert this.initialize}}></div>");

var _class;
let HCaptchaComponent = (_class = class HCaptchaComponent extends Component {
  get config() {
    const _config = getOwner(this).resolveRegistration('config:environment') || {};
    return _config['ember-h-captcha'] || {};
  }
  get options() {
    let _options = {};
    Object.assign(_options, this.config, this.componentOptions);
    return _options;
  }
  get componentOptions() {
    const defaults = ['sitekey', 'theme', 'size', 'tabindex'];
    const options = {};
    defaults.forEach(option => {
      if (isPresent(get(this.args, option))) {
        options[option] = get(this.args, option);
      }
    });
    return options;
  }
  initialize(element) {
    window.__ember_h_captcha_onload = () => {
      this.render(element);
    };
    this.appendScript([`${this.config['jsUrl'] || 'https://hcaptcha.com/1/api.js'}?render=explicit`, 'onload=__ember_h_captcha_onload', this.config['hl'] ? `hl=${this.config['hl']}` : ''].join('&'));
  }
  render(element) {
    const parameters = Object.assign(this.options, {
      callback: this.onSuccessCallback.bind(this),
      'expired-callback': this.onExpiredCallback.bind(this),
      'error-callback': this.onErrorCallback.bind(this)
    });
    this.widgetId = hcaptcha.render(element, parameters);
    this.onRenderCallback();
  }
  onRenderCallback() {
    const action = this.args.onRender;
    if (isPresent(action) && typeof action === 'function') {
      action(this);
    }
  }
  appendScript(src) {
    let scriptTag = document.createElement('script');
    scriptTag.src = src;
    scriptTag.async = true;
    scriptTag.defer = true;
    document.body.appendChild(scriptTag);
  }
  onSuccessCallback(response) {
    const action = this.args.onSuccess;
    if (isPresent(action) && typeof action === 'function') {
      action(response);
    }
  }
  onExpiredCallback() {
    const action = this.args.onExpired;
    if (isPresent(action) && typeof action === 'function') {
      action();
    }
  }
  onErrorCallback(error) {
    const action = this.args.onError;
    if (isPresent(action) && typeof action === 'function') {
      action(error);
    }
  }
  reset() {
    if (isPresent(this.widgetId)) {
      hcaptcha.reset(this.widgetId);
    }
  }
}, (_applyDecoratedDescriptor(_class.prototype, "config", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "config"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "options", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "options"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "componentOptions", [cached], Object.getOwnPropertyDescriptor(_class.prototype, "componentOptions"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "initialize", [action], Object.getOwnPropertyDescriptor(_class.prototype, "initialize"), _class.prototype)), _class);
setComponentTemplate(TEMPLATE, HCaptchaComponent);

export { HCaptchaComponent as default };
//# sourceMappingURL=h-captcha.js.map
